from setuptools import setup

setup(name='utils_distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['utils_distributions'],
      author='Irune Lansorena',
      authoremail='irunelansorena@gmail.com',
      zip_safe=False)
